aboutsummaryrefslogtreecommitdiff
path: root/lib/http.c
diff options
context:
space:
mode:
authorNick Zitzmann <nick@chronosnet.com>2012-07-16 20:20:57 -0600
committerDaniel Stenberg <daniel@haxx.se>2012-07-25 23:22:11 +0200
commitf92779198d07abb18e8a5c4dd3a2e1b7c4c8726a (patch)
tree258327de5670f3570e7a932ce7c94b9fe8d7a510 /lib/http.c
parent9ac5cdfc2f0a0fed15588b8a007c565fa711c9c3 (diff)
darwinssl: fixed freeze involving the multi interface
Previously the curl_multi interface would freeze if darwinssl was enabled and at least one of the handles tried to connect to a Web site using HTTPS. Removed the "wouldblock" state darwinssl was using because I figured out a solution for our "would block but in which direction?" dilemma.
Diffstat (limited to 'lib/http.c')
-rw-r--r--lib/http.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/http.c b/lib/http.c
index 06bdf610c..0c12d1896 100644
--- a/lib/http.c
+++ b/lib/http.c
@@ -1371,9 +1371,10 @@ static CURLcode https_connecting(struct connectdata *conn, bool *done)
}
#endif
-#if defined(USE_SSLEAY) || defined(USE_GNUTLS) || defined(USE_SCHANNEL)
-/* This function is for OpenSSL, GnuTLS and schannel only. It should be
- made to query the generic SSL layer instead. */
+#if defined(USE_SSLEAY) || defined(USE_GNUTLS) || defined(USE_SCHANNEL) || \
+ defined(USE_DARWINSSL)
+/* This function is for OpenSSL, GnuTLS, darwinssl, and schannel only.
+ It should be made to query the generic SSL layer instead. */
static int https_getsock(struct connectdata *conn,
curl_socket_t *socks,
int numsocks)